@@ -4,7 +4,7 @@ BEGIN {
   $Dist::Zilla::MintingProfile::Author::Caelum::AUTHORITY = 'cpan:RKITOVER';
 }
 {
-  $Dist::Zilla::MintingProfile::Author::Caelum::VERSION = '0.04';
+  $Dist::Zilla::MintingProfile::Author::Caelum::VERSION = '0.05';
 }
 
 use strict;
@@ -14,7 +14,7 @@ use 5.008001;
 use Moose;
 use Dist::Zilla::PluginBundle::AVAR ();
 use Dist::Zilla::Plugin::Git::Init ();
-use Dist::Zilla::Plugin::GitHub::Create ();
+use Dist::Zilla::Plugin::GitHub::Create 0.30 ();
 
 with 'Dist::Zilla::Role::MintingProfile::ShareDir';
 
@@ -28,6 +28,8 @@ Dist::Zilla::MintingProfile::Author::Caelum - Basic Minting Profile for @AVAR
 
     dzil setup
 
+    git config --global push.default simple # if you have git >= 1.8
+
     git config --global github.user GitHubLoginName
     git config --global github.password GitHubPassword
 
@@ -37,7 +39,7 @@ Dist::Zilla::MintingProfile::Author::Caelum - Basic Minting Profile for @AVAR
 
     # edit stuff and commit
 
-    git push origin master -u # -u needed only on first push
+    git push origin master -u # only for git < 1.8
 
     dzil release
 
